@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AgentLinkObject.pm - to link objects
-# Copyright (C) 2001-2010 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: AgentLinkObject.pm,v 1.58 2010/11/16 18:13:02 ub Exp $
+# $Id: AgentLinkObject.pm,v 1.62 2012-01-06 13:00:04 mg Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -17,7 +17,7 @@ use warnings;
 use Kernel::System::LinkObject;
 
 use vars qw($VERSION);
-$VERSION = qw($Revision: 1.58 $) [1];
+$VERSION = qw($Revision: 1.62 $) [1];
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -63,6 +63,20 @@ sub Run {
         );
     }
 
+    # permission check
+    my $Permission = $Self->{LinkObject}->ObjectPermission(
+        Object => $Form{SourceObject},
+        Key    => $Form{SourceKey},
+        UserID => $Self->{UserID},
+    );
+
+    if ( !$Permission ) {
+        return $Self->{LayoutObject}->NoPermission(
+            WithHeaderMessage    => 'You need ro permission!',
+            WithHeader => 'yes',
+        );
+    }
+
     # get form params
     $Form{TargetIdentifier} = $Self->{ParamObject}->GetParam( Param => 'TargetIdentifier' )
         || $Form{SourceObject};
@@ -115,6 +129,9 @@ sub Run {
 
         if ( $Self->{ParamObject}->GetParam( Param => 'SubmitDelete' ) ) {
 
+            # challenge token check for write action
+            $Self->{LayoutObject}->ChallengeTokenCheck();
+
             # delete all temporary links older than one day
             $Self->{LinkObject}->LinkCleanup(
                 State  => 'Temporary',
@@ -137,6 +154,14 @@ sub Run {
                 next IDENTIFIER if !$Target[1];    # TargetKey
                 next IDENTIFIER if !$Target[2];    # LinkType
 
+                my $DeletePermission = $Self->{LinkObject}->ObjectPermission(
+                    Object => $Target[0],
+                    Key    => $Target[1],
+                    UserID => $Self->{UserID},
+                );
+
+                next IDENTIFIER if !$DeletePermission;
+
                 # delete link from database
                 my $Success = $Self->{LinkObject}->LinkDelete(
                     Object1 => $Form{SourceObject},
@@ -212,7 +237,7 @@ sub Run {
             TemplateFile => 'AgentLinkObject',
         );
 
-        $Output .= $Self->{LayoutObject}->Footer( Type => 'Small', );
+        $Output .= $Self->{LayoutObject}->Footer( Type => 'Small' );
 
         return $Output;
     }
@@ -226,11 +251,14 @@ sub Run {
         my $TypeIdentifier = $Self->{ParamObject}->GetParam( Param => 'TypeIdentifier' );
 
         # output header
-        my $Output = $Self->{LayoutObject}->Header( Type => 'Small', );
+        my $Output = $Self->{LayoutObject}->Header( Type => 'Small' );
 
         # add new links
         if ( $Self->{ParamObject}->GetParam( Param => 'SubmitLink' ) ) {
 
+            # challenge token check for write action
+            $Self->{LayoutObject}->ChallengeTokenCheck();
+
             # get the link target keys
             my @LinkTargetKeys = $Self->{ParamObject}->GetArray( Param => 'LinkTargetKeys' );
 
@@ -330,6 +358,14 @@ sub Run {
                         $TargetKey    = $TargetKeyOrg;
                     }
 
+                    my $AddPermission = $Self->{LinkObject}->ObjectPermission(
+                        Object => $TargetObject,
+                        Key    => $TargetKey,
+                        UserID => $Self->{UserID},
+                    );
+
+                    next TARGETKEYORG if !$AddPermission;
+
                     # add links to database
                     my $Success = $Self->{LinkObject}->LinkAdd(
                         SourceObject => $SourceObject,
@@ -386,6 +422,16 @@ sub Run {
             },
         );
 
+        # output special block for temporary links
+        # to close the popup without reloading the parent window
+        if ( $Form{Mode} eq 'Temporary' ) {
+
+            $Self->{LayoutObject}->Block(
+                Name => 'TemporaryLink',
+                Data => {},
+            );
+        }
+
         # get search option list
         my @SearchOptionList = $Self->{LayoutObject}->LinkObjectSearchOptionList(
             Object    => $Form{TargetObject},
@@ -415,12 +461,20 @@ sub Run {
         }
 
         # start search
-        my $SearchList = $Self->{LinkObject}->ObjectSearch(
-            Object       => $Form{TargetObject},
-            SubObject    => $Form{TargetSubObject},
-            SearchParams => \%SearchParam,
-            UserID       => $Self->{UserID},
-        );
+        my $SearchList;
+        if (
+            %SearchParam
+            || $Self->{ConfigObject}->Get('Frontend::AgentLinkObject::WildcardSearch')
+            )
+        {
+
+            $SearchList = $Self->{LinkObject}->ObjectSearch(
+                Object       => $Form{TargetObject},
+                SubObject    => $Form{TargetSubObject},
+                SearchParams => \%SearchParam,
+                UserID       => $Self->{UserID},
+            );
+        }
 
         # remove the source object from the search list
         if ( $SearchList && $SearchList->{ $Form{SourceObject} } ) {
@@ -439,15 +493,12 @@ sub Run {
         }
 
         # get already linked objects
-        my $LinkListWithData = {};
-        if ( $SearchList && $SearchList->{ $Form{TargetObject} } ) {
-            $LinkListWithData = $Self->{LinkObject}->LinkListWithData(
-                Object => $Form{SourceObject},
-                Key    => $Form{SourceKey},
-                State  => $Form{State},
-                UserID => $Self->{UserID},
-            );
-        }
+        my $LinkListWithData = $Self->{LinkObject}->LinkListWithData(
+            Object => $Form{SourceObject},
+            Key    => $Form{SourceKey},
+            State  => $Form{State},
+            UserID => $Self->{UserID},
+        );
 
         if ( $LinkListWithData && $LinkListWithData->{ $Form{TargetObject} } ) {
 
