@@ -3,7 +3,7 @@
 # bin/otrs.AddService.pl - add new Services
 # Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
 # --
-# $Id: otrs.AddService.pl,v 1.1.2.2 2012/06/27 21:56:51 mb Exp $
+# $Id: otrs.AddService.pl,v 1.1.2.4 2012-10-29 09:19:06 ub Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -17,7 +17,7 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
@@ -29,6 +29,10 @@ use FindBin qw($RealBin);
 use lib dirname($RealBin);
 use lib dirname($RealBin) . '/Kernel/cpan-lib';
 use lib dirname($RealBin) . '/Custom';
+
+use vars qw($VERSION);
+$VERSION = qw($Revision: 1.1.2.4 $) [1];
+
 use Getopt::Std;
 
 use Kernel::Config;
@@ -45,7 +49,7 @@ my $NoOptions = $ARGV[0] ? 0 : 1;
 
 # get options
 my %Opts;
-getopts( 'hg:n:p:S:c:r:u:l:', \%Opts );
+getopts( 'hn:p:c:', \%Opts );
 
 if ( $Opts{h} || $NoOptions ) {
     print STDERR "Usage: $FindBin::Script -n <Name> -p <Parent> -c <Comment>\n";
@@ -75,7 +79,7 @@ if ( $Opts{p} ) {
         UserID => 1,
     );
     if ( !$Param{ParentID} ) {
-        print STDERR "ERROR: Can't add Service: Parent $Opts{p} does not exist!\n";
+        print STDERR "ERROR: Can't add Service: Parent '$Opts{p}' does not exist!\n";
         exit 1;
     }
     $ServiceName = $Opts{p} . '::';
@@ -90,7 +94,7 @@ my %ServiceList = $CommonObject{ServiceObject}->ServiceList(
 );
 my %Reverse = reverse %ServiceList;
 if ( $Reverse{$ServiceName} ) {
-    print STDERR "ERROR: Can't add Service: Service $ServiceName already exists!\n";
+    print STDERR "ERROR: Can't add Service: Service '$ServiceName' already exists!\n";
     exit 1;
 }
 
