@@ -1,6 +1,9 @@
-#!/usr/bin/perl
+#!/usr/bin/perl -w
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# bin/otrs.AddTicketType.pl - add new Ticket Types
+# Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+# --
+# $Id: otrs.AddTicketType.pl,v 1.3 2011-03-25 13:53:58 ep Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -9,12 +12,12 @@
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
@@ -24,8 +27,7 @@ use warnings;
 use File::Basename;
 use FindBin qw($RealBin);
 use lib dirname($RealBin);
-use lib dirname($RealBin) . '/Kernel/cpan-lib';
-use lib dirname($RealBin) . '/Custom';
+use lib dirname($RealBin) . "/Kernel/cpan-lib";
 
 use Kernel::Config;
 use Kernel::System::Encode;
@@ -34,41 +36,41 @@ use Kernel::System::DB;
 use Kernel::System::Type;
 use Kernel::System::Main;
 
-my %CommonObject;
-
-# create common objects
-$CommonObject{ConfigObject} = Kernel::Config->new();
-$CommonObject{EncodeObject} = Kernel::System::Encode->new(%CommonObject);
-$CommonObject{LogObject}    = Kernel::System::Log->new( %CommonObject, LogPrefix => 'OTRS-otrs.TicketType' );
-$CommonObject{MainObject}   = Kernel::System::Main->new(%CommonObject);
-$CommonObject{DBObject}     = Kernel::System::DB->new(%CommonObject);
-$CommonObject{TypeObject}   = Kernel::System::Type->new(%CommonObject);
-
 my %Param;
-my %Options;
+my %CommonObject;
+my %opts;
 
 use Getopt::Std;
-getopts( 'n:h', \%Options );
+getopts( 'n:h', \%opts );
 
-if ( $Options{h} ) {
+if ( $opts{h} ) {
     print STDERR "Usage: $FindBin::Script -n <Type>\n";
     exit;
 }
 
-if ( !$Options{n} ) {
+if ( !$opts{n} ) {
     print STDERR "ERROR: Need -n <Type>\n";
     exit 1;
 }
 
+# create common objects
+$CommonObject{ConfigObject} = Kernel::Config->new();
+$CommonObject{EncodeObject} = Kernel::System::Encode->new(%CommonObject);
+$CommonObject{LogObject}
+    = Kernel::System::Log->new( %CommonObject, LogPrefix => 'OTRS-otrs.TicketType' );
+$CommonObject{MainObject} = Kernel::System::Main->new(%CommonObject);
+$CommonObject{DBObject}   = Kernel::System::DB->new(%CommonObject);
+$CommonObject{TypeObject} = Kernel::System::Type->new(%CommonObject);
+
 # user id of the person adding the record
 $Param{UserID} = '1';
 
 # Validrecord
 $Param{ValidID} = '1';
-$Param{Name} = $Options{n} || '';
+$Param{Name} = $opts{n} || '';
 
 if ( my $RID = $CommonObject{TypeObject}->TypeAdd(%Param) ) {
-    print "Ticket type '$Options{n}' added. Type id is '$RID'\n";
+    print "Ticket type '$opts{n}' added. Type id is '$RID'\n";
 }
 else {
     print STDERR "ERROR: Can't add type\n";
