@@ -1,9 +1,12 @@
 // --
-// Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+// Core.Agent.Admin.GenericInterfaceWebserviceHistory.js - provides the special module functions for the GenericInterface WebserviceHistory.
+// Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+// --
+// $Id: Core.Agent.Admin.GenericInterfaceWebserviceHistory.js,v 1.12 2011-07-08 21:42:20 cr Exp $
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
-// the enclosed file COPYING for license information (GPL). If you
-// did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+// the enclosed file COPYING for license information (AGPL). If you
+// did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 // --
 
 "use strict";
@@ -13,44 +16,19 @@ Core.Agent = Core.Agent || {};
 Core.Agent.Admin = Core.Agent.Admin || {};
 
 /**
- * @namespace Core.Agent.Admin.GenericInterfaceWebserviceHistory
- * @memberof Core.Agent.Admin
- * @author OTRS AG
+ * @namespace
+ * @exports TargetNS as Core.Agent.Admin.GenericInterfaceWebserviceHistory
  * @description
  *      This namespace contains the special module functions for the GenericInterface WebserviceHistory module.
  */
 Core.Agent.Admin.GenericInterfaceWebserviceHistory = (function (TargetNS) {
 
-    /**
-     * @name Init
-     * @memberof Core.Agent.Admin.GenericInterfaceWebserviceHistory
-     * @function
-     * @description
-     *      This function initialize the module.
-     */
-    TargetNS.Init = function () {
-
-        TargetNS.WebserviceID = parseInt(Core.Config.Get('WebserviceID'), 10);
-
-        // add click binds
-        $('#ExportButton').on('click', function(){
-            $('#Subaction').attr('value','Export');
-            $('#ActionForm').submit();
-        });
-
-        $('#RollbackButton').on('click', TargetNS.ShowRollbackDialog);
-
-        TargetNS.GetWebserviceList();
 
+    TargetNS.Init = function (Params) {
+        TargetNS.WebserviceID = parseInt(Params.WebserviceID, 10);
+        TargetNS.Localization = Params.Localization;
     };
 
-    /**
-     * @name GetWebserviceList
-     * @memberof Core.Agent.Admin.GenericInterfaceWebserviceHistory
-     * @function
-     * @description
-     *      Get list of webservices via AJAX..
-     */
     TargetNS.GetWebserviceList = function() {
         var Data = {
             Action: 'AdminGenericInterfaceWebserviceHistory',
@@ -64,39 +42,36 @@ Core.Agent.Admin.GenericInterfaceWebserviceHistory = (function (TargetNS) {
         $('.WebserviceListWidget').addClass('Loading');
 
         Core.AJAX.FunctionCall(Core.Config.Get('CGIHandle'), Data, function (Response) {
-            var HTML = '',
-                Counter;
-
             if (!Response || !Response.LogData) {
-                alert(Core.Language.Translate('An error occurred during communication.'));
+                alert(TargetNS.Localization.WebserviceHistoryErrorMsg);
                 return;
             }
 
             $('.WebserviceListWidget').removeClass('Loading');
 
             if (!Response.LogData.length) {
-                $('#WebserviceList tbody').empty().append('<tr><td colspan="3">' + Core.Language.Translate('No data found.') + '</td></tr>');
+                $('#WebserviceList tbody').empty().append('<tr><td colspan="3">' + TargetNS.Localization.NoDataFoundMsg + '</td></tr>');
             }
             else {
                 $('#WebserviceList tbody').empty();
-
+                var HTML = '',
                 Counter = Response.LogData.length;
 
                 $.each(Response.LogData, function(){
                     HTML += '<tr>';
 
-                    HTML += '<td><a href="#" class="AsBlock">' + Counter +
+                    HTML += '<td><a href="#" class="AsBlock">' + Counter + 
                         '<input type="hidden" class="WebserviceHistoryID" value="' + this.ID + '" />' +
                         '<input type="hidden" class="WebserviceHistoryVersion" value="' + Counter + '" />' +
                     '</a></td>';
                     HTML += '<td><a href="#" class="AsBlock">' + this.CreateTime + '</a></td>';
                     HTML += '</tr>';
-                    Counter--;
+                    Counter --;
 
                 });
                 $('#WebserviceList tbody').html(HTML);
 
-                $('#WebserviceList a').on('click', function() {
+                $('#WebserviceList a').bind('click', function(Event) {
                     var WebserviceHistoryID = $(this).blur().parents('tr').find('input.WebserviceHistoryID').val(),
                     WebserviceHistoryVersion = $(this).blur().parents('tr').find('input.WebserviceHistoryVersion').val();
 
@@ -109,15 +84,6 @@ Core.Agent.Admin.GenericInterfaceWebserviceHistory = (function (TargetNS) {
         }, 'json');
     };
 
-    /**
-     * @name LoadWebserviceHistoryDetails
-     * @memberof Core.Agent.Admin.GenericInterfaceWebserviceHistory
-     * @function
-     * @param {String} WebserviceHistoryID
-     * @param {String} WebserviceHistoryVersion
-     * @description
-     *      This function initialize the module.
-     */
     TargetNS.LoadWebserviceHistoryDetails = function(WebserviceHistoryID, WebserviceHistoryVersion) {
 
         var Data = {
@@ -131,8 +97,8 @@ Core.Agent.Admin.GenericInterfaceWebserviceHistory = (function (TargetNS) {
         $('.WebserviceListWidget').addClass('Loading');
 
         Core.AJAX.FunctionCall(Core.Config.Get('CGIHandle'), Data, function (Response) {
-            if (!Response || !Response.LogData) {
-                alert(Core.Language.Translate('An error occurred during communication.'));
+            if (!Response || !Response.LogData ) {
+                alert(TargetNS.Localization.WebserviceHistoryErrorMsg);
                 return;
             }
             $('.WebserviceListWidget').removeClass('Loading');
@@ -144,17 +110,17 @@ Core.Agent.Admin.GenericInterfaceWebserviceHistory = (function (TargetNS) {
                 );
                 $('#WebserviceHistoryDetails .ConfigCode pre').empty();
                 $('#WebserviceHistoryDetails .ConfigCode pre').append(
-                    '<span class="ErrorMessage">' + Core.Language.Translate('No data found.') + '</span>'
+                    '<span class="ErrorMessage">' + TargetNS.Localization.NoDataFoundMsg + '</span>'
                 );
                 $('#WebserviceHistoryDetails').css('visibility', 'visible').show();
                 $('#WebserviceHistoryDetails .LightRow').hide();
             }
             else {
 
-                $('#WebserviceHistoryID').attr('value', WebserviceHistoryID);
+                $('#WebserviceHistoryID').attr('value',WebserviceHistoryID);
                 $('#WebserviceHistoryDetails .ControlRow').empty();
                 $('#WebserviceHistoryDetails .ControlRow').append(
-                    '<h2>History Details: Version ' + WebserviceHistoryVersion + ', ' + Response.LogData.CreateTime + '</h2>'
+                    '<h2>History Details: Version ' + WebserviceHistoryVersion + ', ' + Response.LogData.CreateTime +  '</h2>'
                 );
 
                 $('#WebserviceHistoryDetails .ConfigCode pre').empty();
@@ -169,35 +135,27 @@ Core.Agent.Admin.GenericInterfaceWebserviceHistory = (function (TargetNS) {
         }, 'json');
     };
 
-    /**
-     * @name ShowRollbackDialog
-     * @memberof Core.Agent.Admin.GenericInterfaceWebserviceHistory
-     * @function
-     * @returns {Boolean} Returns false.
-     * @param {Object} Event - The browser event object, e.g. of the clicked DOM element.
-     * @description
-     *      Shows a dialog to rollback log.
-     */
+
     TargetNS.ShowRollbackDialog = function(Event){
 
         Core.UI.Dialog.ShowContentDialog(
             $('#RollbackDialogContainer'),
-            Core.Language.Translate('Restore web service configuration'),
+            TargetNS.Localization.RollbackLogMsg,
             '240px',
             'Center',
             true,
             [
                 {
-                    Label: Core.Language.Translate('Cancel'),
+                    Label: TargetNS.Localization.CancelMsg,
                     Class: 'Primary',
                     Function: function () {
                         Core.UI.Dialog.CloseDialog($('#RollbackDialog'));
                     }
                 },
                 {
-                    Label: Core.Language.Translate('Restore web service configuration'),
+                    Label: TargetNS.Localization.RollbackLogMsg,
                     Function: function () {
-                        $('#Subaction').attr('value', 'Rollback');
+                        $('#Subaction').attr('value','Rollback');
                         $('#ActionForm').submit();
                     }
                 }
@@ -208,7 +166,6 @@ Core.Agent.Admin.GenericInterfaceWebserviceHistory = (function (TargetNS) {
         return false;
     };
 
-    Core.Init.RegisterNamespace(TargetNS, 'APP_MODULE');
 
     return TargetNS;
-}(Core.Agent.Admin.GenericInterfaceWebserviceHistory || {}));
+}(Core.Agent.Admin.GenericInterfaceWebserviceHistory || {}));
\ No newline at end of file
